# ghstars

A CLI tool to collect and render as a staic website most notable stargazers for your GitHub projects.

## Usage

1. Clone: `gt clone https://github.com/orsinium-labs/ghstars.git && cd ghstars`
1. [Generate GitHub API token](https://github.com/settings/tokens)
1. Fetch data: `ghstars fetch --token YOUR_TOKEN --orgs YOUR_ORG`
1. Generate HTML: `ghstars render`
